% This script gives an example of running a FORWARD (NO OPTIMIZATION) "batch_unit" batch run.
% An example database, watershed characteristic file, and rainfall loss parameter input file are used.
% An initial abstraction with constant-loss rainfall loss model used.

% clean up the workspace...
close all; fclose all; diary off; clear; pack; clc;

% define the input files and directories...
databasedir = ['.',filesep,'EXAMPLE_INPUT_DATA'];         % raw data database directory to use.
WScharfile  = fullfile(databasedir,'EXAMPLE_WSchar.csv'); % watershed characteristics file to use.
c0file      = fullfile(databasedir,'EXAMPLE_C0.csv');     % loss parameter file to use.

% define the output files and directories...
tag         = 'EXAMPLE';  % output label for file/directory names (can be used to manage multiple output directories).
outdir      = ['.',filesep,'OUTPUT_',datestr(now,'yyyymmdd_HH.MM'),'_',tag,filesep];
outfile     = ['OUTPUT_', tag,'.csv'];
logfile     = ['LOGFILE_',tag,'.log'];

% perform the batch run...
batch_unit( ...
            'start_stop', [1,inf], ...   % run all runs found in the 'datadir' specified below.
                          ...
                  'Lfun', 'AC2', ...     % AC2 = use initial Abstraction/Constant loss (2-parameter) rainfall loss function.
              'opt_meth', 'none', ...    % none = no optimization (forward modeling only).
                          ...
                    'c0', c0file, ...    % c0 file specified above containing the loss function parameters to use in forward modeling.
                          ...
                'db_obj', 0, ...         % debug (1) or do not debug (0) the objective function (debugging gives optimization diagnostics but stops the batch).
              'save_pdf', 1, ...         % save (1) or don't save (0) output PDFs.
                          ...
            'use_synthP', 0, ...         % use synthetic (1) or use non-synthetic (actual raw) (0) rainfall.
               'P_trim1', 0.01, ...      % percent to trim the rainfall at the starting tail.
               'P_trim2', 0.01, ...      % percent to trim the rainfall at the trailing tail.
              'no_neg_P', 1, ...         % do not allow (1) or allow (0) negative rainfall after applying loss model.
           'no_neg_loss', 1, ...         % do not allow (1) or allow (0) negative rainfall loss function values (negative values result in precipitation gains).
                          ...
                'fracQp', 0.01, ...      % extend the hydrograph model until it decays to this fraction of the peak discharge.
 'sim_obs_trim_pad_meth', 'pad_to_longer', ...  % pad the simulated and observed data with 0's to the longer of the 2.
     'max_array_size_MB', 750, ...              % maximum allowable convolution matrix size in megabytes (prevents OUT OF MEMORY errors that stop the batch).
         'USGS_DEM_AREA', 'USGS', ...           % use either the 'USGS' or 'DEM' area specified in the watershed characteristics file.
                          ...
               'datadir', databasedir, ...      % database directory to use.
              'charfile', WScharfile, ...       % watershed characteristics file to use.
       'use_last_fnames', 0, ...                % use the last data files found in 'datadir' above (1) or find all data files from scratch (0).
                'outdir', outdir, ...           % output directory to use. 
               'outfile', outfile, ...          % output text file directory/name to use.
               'logfile', logfile);             % output log file directory/name to use.

return;

