function dy = bRcT_diff(x,y)
% USAGE: dy = bRcT_diff(x,y)
%
% DESCRIPTION: This function differentiates an input data set given by the
%   vectors x and y. A "backwards dy" and "centered dx" method is used.
%
% INPUT:
%   x - numeric column vector containing the x data to differentiate.
%   y - numeric column vector containing the y data to differentiate.
%
% OUTPUT:
%   dy - numeric vector containing the derivative of the input data at the
%        x data points.
%
% Written by: Joe Vrabel, USGS May2006

usage = 'USAGE: dy = bRcT_diff(x,y)';

% Check input...
if nargin ~= 2,
    disp(usage); error('Incorrect number of input arguments.');
end
if ~isnumeric(x),
    disp(usage); error('Input argument ''x'' must be a numeric vector.');
end
if ~isnumeric(y),
    disp(usage); error('Input argument ''y'' must be a numeric vector.');
end
if (size(x,1) < 3) || (size(x,2) ~= 1),
    disp(usage); error('Input argument ''x'' must be a column vector with at least 3 elements.');
end
if (size(y,1) < 3) || (size(y,2) ~= 1),
    disp(usage); error('Input argument ''y'' must be a column vector with at least 3 elements.');
end
if length(x) ~= length(y),
    disp('usage'); error('Input vectors ''x'' and ''y'' must have the same number of elements.');
end

n = length(x);
dy = NaN(size(y));

% handle starting point...
dr = y(2) - y(1);
dt = (x(2) - x(1))/2;
dy(1) = dr/dt;

% handles center points...
for i = 2:n-1,
    dr = y(i) - y(i-1);
    dt = (x(i)-x(i-1))/2 + (x(i+1)-x(i))/2;
    dy(i) = dr/dt;
end

% handles end point...
dr = y(end) - y(end-1);
dt = (x(end) - x(end-1));
dy(end) = dr/dt;

return;

