function [K] = calc_K(L,D)
% USAGE: [K] = calc_K(L,D)
%
% DESCRIPTION: This function calculates the shape parameter K used in the
%   gamma unit hydrograph.
%
% INPUT:
%   L - channel length [mi]
%   D - development indicator [0=undeveloped, 1=developed]
%
% OUTPUT:
%   K - gamma unit hydrograph shape parameter [dimensionless]
%
% Written by: Joe Vrabel, USGS May2006

usage = 'USAGE: [K] = calc_K(L,D)';

% check arguments...
if nargin ~= 2,
    disp(usage);
    error('Incorrect number of input arguments.');
end

% calculate K...
a = 0.481;
b = -0.0782;
c = 0.140;
K = (10.^(a+b.*D)) .* (L.^c);

return;
