function [Q,A] = calc_Q(U,P)
% USAGE: [Q,A] = calc_Q(U,P)
%
% DESCRIPTION: This function computes the streamflow hydrograph for a storm
%   given a unit hydrograph and excess precip input.
%
% INPUT:
%   U - column vector containing unit hydrograph ordinates [CFS in 5min intervals].
%   P - column vector containing excess precip input [inches in 5min intervals].
%
% OUTPUT:
%   Q - column vector containing resulting streamflow [CFS in 5min intervals].
%   A (optional) - convolution matrix created to find Q.
%
% Written by: Joe Vrabel, USGS July2006

usage = 'USAGE: [Q,A] = calc_Q(U,P)';

% check arguments...
if nargin ~= 2,
    disp(usage);
    error('Incorrect number of input arguments.');
end

% build P (precip) matrix...
p = length(P); % number of precip values.
u = length(U); % number of unit hydrograph ordinates.
n = u+p-1;     % number of flow values.
A = zeros(n,u); % initialize convolution matrix.

% build convolution matrix...
for i = 1:u,
    A(i:(i+p-1),i) = P;
end
% (alternate technique)
% for i = 1:u,
%     A(i:(i+p-1),i) = U(i)*P;
% end
% now: Q = sum(A,2);

% multiple convolution matrix with the unit hydrograph to find Q...
Q = A*U;

return;

