function [Tp] = calc_Tp(S,L,D)
% USAGE: [Tp] = calc_Tp(S,L,D)
%
% DESCRIPTION: This function calculates the time to peak given
%   channel slope, length, and development status.
%
% INPUT:
%   S - slope of the channel [dimensionless]
%   L - channel length [mi]
%   D - development indicator [0=undeveloped, 1=developed]
%
% OUTPUT:
%   Tp - time to peak [hrs]
%
% Written by: Joe Vrabel, USGS July2006

usage = 'USAGE: [Tp] = calc_Tp(S,L,D)';

% check arguments...
if nargin ~= 3,
    disp(usage);
    error('Incorrect number of input arguments.');
end

% calculate Tp...
a = -1.49;
b = -0.354;
c =  0.602;
d = -0.672;
Tp = (10.^(a+b.*D)) .* (L.^c) .* (S.^d);

return;
