function [U] = calc_U(T,qp,Tp,K)
% USAGE: [U] = calc_U(T,qp,Tp,K)
%
% DESCRIPTION: This function generates the gamma unit hydrograph.
%
% INPUT:
%   T  - column vector containing times to output discharge [hrs].
%   qp - peak discharge [CFS]
%   Tp - time to peak [hrs]
%   K  - shape parameter of the gamma unit hydrograph [dimensionless].
%
% OUTPUT:
%   U - column vector with the unit hydrograph values at times T [CFS]
%
% Written by: Joe Vrabel, USGS July2006

usage = 'USAGE: [U] = calc_U(T,qp,Tp,K)';

% check arguments...
if nargin ~= 4,
    disp(usage);
    error('Incorrect number of input arguments.');
end

U = qp.*( ( (T./Tp).*exp(1 - T./Tp) ).^K ); % T in [hrs], gives Q in [CFS].

return;
