function [qp] = calc_qp(K,Tp,area)
% USAGE: [qp] = calc_qp(K,Tp,area)
%
% DESCRIPTION: This function calculates the peak discharge given the
%   time to peak and the shape parameter K.
%
% INPUT:
%   K  - shape parameter of the gamma unit hydrograph [dimensionless].
%   Tp - time to peak [hrs]
%   area - drainage area [mi^2]
%
% OUTPUT:
%   qp - peak discharge [CFS]
%
% NOTES: the following relation is used:
%    V = 1 = (qp)(Tp)gamma(K)(e/K)^k
%
% Written by: Joe Vrabel, USGS July2006

usage = 'USAGE: [qp] = calc_qp(K,Tp,area)';

% check arguments...
if nargin ~= 3,
    disp(usage);
    error('Incorrect number of input arguments.');
end

V = 1;
e = exp(1);
qp = ((5280^2)*area*V) ./ ((12*(60^2)) .* Tp .* gamma(K) .* ((e./K).^K));

return;
