function Tunit = get_Tunit(qp,Tp,K,frac)
% USAGE: Tunit = get_Tunit(qp,Tp,K,frac)
%
% DESCRIPTION: This function finds the time needed for the gamma unit
% hydrograph to diminish to the specified fraction (frac) of the peak.
%
% INPUT:
%   qp - peak discharge parameter of the gamma unit hydrograph [CFS]
%   Tp - time-to-peak parameter of the gamma unit hydrograph [hrs]
%   K  - shape parameter of the gamma unit hydrograph [dimensionless]
%   frac - fraction of the peak discharge [dimensionless]
%
% OUTPUT:
%   use_T - time column vector, in 5min increments, from t=0 to the amount
%           of time needed for the unit hydrograph to diminish to the specified
%           fraction (frac).
%
% Written by Joe Vrabel, USGS June2006

usage = 'USAGE: Tunit = get_Tunit(qp,Tp,K,frac)';

% check input...
if nargin ~= 4,
    disp(usage);
    error('Incorrect number of input arguments.');
end
if (~isnumeric(qp)) || (numel(qp) ~= 1),
    disp(usage);
    error('Input argument ''qp'' must be a numeric scalar.');
end
if (~isnumeric(Tp)) || (numel(Tp) ~= 1),
    disp(usage);
    error('Input argument ''Tp'' must be a numeric scalar.');
end
if (~isnumeric(K)) || (numel(K) ~= 1),
    disp(usage);
    error('Input argument ''K'' must be a numeric scalar.');
end
if (~isnumeric(frac)) || (numel(frac) ~= 1),
    disp(usage);
    error('Input argument ''frac'' must be a numeric scalar.');
end

% find time (hours) after Tp that gives frac of qp...
for T = Tp:5/60:100*Tp,
    if calc_U(T,qp,Tp,K) <= frac*qp,
        Tmax = T;
        break;
    end
end

% build output time column vector from 0 to Tmax in 5min increments...
Tunit  = (0:(5/60):Tmax)';

% plot(Tunit,calc_U(Tunit,qp,Tp,K));error('asdasd')

return;