function [staid] = get_staid(fname)
% USAGE: [staid] = get_staid(fname)
%
% DESCRIPTION: This function extract a station ID from a file name.
%   The file name must be formatted as: xxxxxxxx########xxxxxxxxxx.ext,
%   where ######## is the 8-digit station ID.
%
% INPUT:
%   fname - (string) the file name.
%
% OUTPUT:
%   staid - (integer) the station ID.
%
% Written by: Joe Vrabel, USGS Aug2006

% hydro file name format: 'unit_sta08155200_1978_0606.dat'
% hyeto file name format: 'rain_sta08155200_1978_0606.dat'
[fullpath,name,ext,vers] = fileparts(fname);
if length(name) < 16,
    error(['Unexpected file name encountered: ',fname]);
end
staid = str2double(name(9:16));
return;