function [m,b,r2] = regress_mbr(x,y)
% USAGE: [m,b,r2] = regress_mbr(x,y)
%
% DESCRIPTION: This function takes 2 vectors x and y, performs a least-squares
%   regression on them, and returns the slope, y-intercept, and r-squared from
%   the resulting linear fit. x any y may be either column or row vectors.
%
% INPUT:
%   x - vector of the x-values.
%   y - vector of the y-values.
%
% OUTPUT:
%   m  - slope of the least-squares linear fit.
%   b  - y-intercept of the least-squares linear fit.
%   r2 - r-squared of the least squares fit.
%
% Written by: Joe Vrabel, USGS July2006

usage = 'USAGE: [m,b,r2] = regress_mbr(x,y)';

% check inputs...
if nargin ~= 2,
    disp(usage);
    error('Incorrect number of input arguments.');
end
if ~isnumeric(x) || ~isnumeric(y) || ~isvector(x) || ~isvector(y)
    disp(usage);
    error('Input arguments ''x'' and ''y'' must be numeric vectors');
end

% convert x and y to column vectors, if needed...
if size(x,1) == 1, % row vector - change to column vector.
    x = x';
end
if size(y,1) == 1, % row vector - change to column vector.
    y = y';
end

[B,Bint,r,rint,stats] = regress(y,[ones(size(x)),x]);
r2 = stats(1);
m = B(2);
b = B(1);

% % debug...
% plot(x,y,'ko'); hold on;
% Yfit = @(Xfit) m.*Xfit + b;
% X = [min(x),max(x)]
% Y = Yfit(X)
% plot(X,Y,'r')
% lsline % should be same as above line.

return;


